import { LoggerProps } from '@dopt/logger';
import { DocumentContext, ElementContext, SemanticContext, VisualContext, AssistantQueryParams, AssistantCompletionsRequestBody, StatusChunk, AnswerChunk } from '@dopt/ai-assistant-definition';

interface AssistantContextProps {
    document?: boolean | DocumentContext['value'];
    element?: Element | ElementContext['value'];
    semantic?: boolean | SemanticContext['value'];
    visual?: boolean | VisualContext['value'];
}
declare function formAssistantContext({ document, element, semantic, visual, }: AssistantContextProps): Promise<{
    document?: {
        type: "document";
        value: {
            url: string;
            title: string;
            width: number;
            height: number;
        };
    } | undefined;
    element?: {
        type: "element";
        value: {
            position: {
                top: number;
                left: number;
            };
            content: string;
            tag: string;
        };
    } | undefined;
    semantic?: {
        type: "semantic";
        value: {
            semanticContent: string;
            neighboringSemanticContent: string;
        };
    } | undefined;
    visual?: {
        type: "visual";
        value: string;
    } | undefined;
}>;

interface Properties {
    /**
     * The userId you're requesting completions on behalf of.
     */
    userId: string | undefined;
    /**
     * An optional groupId for that userId.
     */
    groupId?: string | undefined;
    /**
     * Your AI API key.
     */
    apiKey: string;
    environment?: string;
    /**
     * The underlying model you want answers generated with.
     * This parameter is currently ignored by the API.
     * It may be exposed in the future.
     */
    model?: AssistantQueryParams['model'];
    logLevel?: LoggerProps['logLevel'];
}
declare class Assistant {
    private apiKey;
    private userId?;
    private groupId?;
    private environment;
    private model;
    private logger;
    private client;
    constructor({ apiKey, userId, groupId, environment, model, logLevel, }: Properties);
    configure(config: Partial<Pick<Properties, 'userId'>>): void;
    completions(sid: string, { query, context, }: {
        query: AssistantCompletionsRequestBody['query'];
        context: AssistantContextProps;
    }, callbacks?: {
        onStatus?: (status: StatusChunk['status'] | null) => void;
        onContent?: (content: string) => void;
        onComplete?: (answer: AnswerChunk['answer'], sources: AnswerChunk['sources']) => void;
        onError?: (error: unknown) => void;
    }): () => boolean;
}

export { Assistant, type AssistantContextProps, type Properties, formAssistantContext };
